Documentation
¶
Overview ¶
Package cainjector is the internal version of the cainjector config API. +groupName=cainjector.config.cert-manager.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: cainjector.GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type CAInjectorConfiguration ¶
type CAInjectorConfiguration struct {
metav1.TypeMeta
// Paths to a kubeconfig. Only required if out-of-cluster.
KubeConfig string
// If set, this limits the scope of cert-manager to a single namespace and
// ClusterIssuers are disabled. If not specified, all namespaces will be
// watched"
Namespace string
// LeaderElectionConfig configures the behaviour of the leader election
LeaderElectionConfig shared.LeaderElectionConfig
// EnableDataSourceConfig determines whether cainjector's control loops will watch
// cert-manager resources as potential sources of CA data.
EnableDataSourceConfig EnableDataSourceConfig
// EnableInjectableConfig determines whether cainjector's control loops will watch
// cert-manager resources as potential targets for CA data injection.
EnableInjectableConfig EnableInjectableConfig
// Enable profiling for cainjector.
EnablePprof bool
// The host and port that Go profiler should listen on, i.e localhost:6060.
// Ensure that profiler is not exposed on a public address. Profiler will be
// served at /debug/pprof.
PprofAddress string
// https://pkg.go.dev/k8s.io/component-base@v0.27.3/logs/api/v1#LoggingConfiguration
Logging logsapi.LoggingConfiguration
// featureGates is a map of feature names to bools that enable or disable experimental
// features.
FeatureGates map[string]bool
}
func (*CAInjectorConfiguration) DeepCopy ¶
func (in *CAInjectorConfiguration) DeepCopy() *CAInjectorConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CAInjectorConfiguration.
func (*CAInjectorConfiguration) DeepCopyInto ¶
func (in *CAInjectorConfiguration) DeepCopyInto(out *CAInjectorConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CAInjectorConfiguration) DeepCopyObject ¶
func (in *CAInjectorConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EnableDataSourceConfig ¶
type EnableDataSourceConfig struct {
// Certificates detemines whether cainjector's control loops will watch
// cert-manager Certificate resources as potential sources of CA data.
Certificates bool
}
func (*EnableDataSourceConfig) DeepCopy ¶
func (in *EnableDataSourceConfig) DeepCopy() *EnableDataSourceConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnableDataSourceConfig.
func (*EnableDataSourceConfig) DeepCopyInto ¶
func (in *EnableDataSourceConfig) DeepCopyInto(out *EnableDataSourceConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnableInjectableConfig ¶
type EnableInjectableConfig struct {
// ValidatingWebhookConfigurations determines whether cainjector
// will spin up a control loop to inject CA data to annotated
// ValidatingWebhookConfigurations
ValidatingWebhookConfigurations bool
// MutatingWebhookConfigurations determines whether cainjector
// will spin up a control loop to inject CA data to annotated
// MutatingWebhookConfigurations
MutatingWebhookConfigurations bool
// CustomResourceDefinitions determines whether cainjector
// will spin up a control loop to inject CA data to annotated
// CustomResourceDefinitions
CustomResourceDefinitions bool
// APIServices determines whether cainjector
// will spin up a control loop to inject CA data to annotated
// APIServices
APIServices bool
}
func (*EnableInjectableConfig) DeepCopy ¶
func (in *EnableInjectableConfig) DeepCopy() *EnableInjectableConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnableInjectableConfig.
func (*EnableInjectableConfig) DeepCopyInto ¶
func (in *EnableInjectableConfig) DeepCopyInto(out *EnableInjectableConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package install installs the API group, making it available as an option to all of the API encoding/decoding machinery.
|
Package install installs the API group, making it available as an option to all of the API encoding/decoding machinery. |
|
+groupName=cainjector.config.cert-manager.io
|
+groupName=cainjector.config.cert-manager.io |