accounts

package
v1.19.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrNotFound = errors.New("ACME client for issuer not initialised/available")

ErrNotFound is returned by GetClient if there is no ACME client registered.

Functions

This section is empty.

Types

type Getter

type Getter interface {
	// GetClient will fetch a registered client using the UID of the Issuer
	// resources that constructed it.
	// If no client is found, ErrNotFound will be returned.
	GetClient(uid string) (acmecl.Interface, error)

	// ListClients will return a full list of all ACME clients by their UIDs.
	// This can be used to enumerate all registered clients and call RemoveClient
	// on any clients that should no longer be registered, e.g., because their
	// corresponding Issuer resource has been deleted.
	ListClients() map[string]acmecl.Interface
}

Getter is an interface that contains the read-only methods for a registry.

type NewClientFunc

type NewClientFunc func(options NewClientOptions) acmecl.Interface

NewClientFunc is a function type for building a new ACME client.

func NewClient

func NewClient(
	metrics *metrics.Metrics,
	userAgent string,
) NewClientFunc

NewClient is an implementation of NewClientFunc that returns a real ACME client.

type NewClientOptions added in v1.19.0

type NewClientOptions struct {
	SkipTLSVerify bool
	CABundle      []byte
	Server        string
	PrivateKey    *rsa.PrivateKey
}

type Registry

type Registry interface {
	// AddClient will ensure the registry has a stored ACME client for the Issuer
	// object with the given UID, configuration and private key.
	AddClient(uid string, options NewClientOptions)

	// RemoveClient will remove a registered client using the UID of the Issuer
	// resource that constructed it.
	RemoveClient(uid string)

	// IsKeyCheckSumCached checks if the private key checksum is cached with registered client.
	// If not cached, the account is re-verified for the private key.
	IsKeyCheckSumCached(lastPrivateKeyHash string, privateKey *rsa.PrivateKey) bool

	Getter
}

A registry provides a means to store and access ACME clients using an issuer objects UID. This is used as a shared cache of ACME clients across various controllers.

func NewDefaultRegistry

func NewDefaultRegistry(newClientFunc NewClientFunc) Registry

NewDefaultRegistry returns a new default instantiation of a client registry.

Directories

Path Synopsis

Jump to