Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the webhook config API. +k8s:deepcopy-gen=package,register +groupName=webhook.config.cert-manager.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( SchemeBuilder runtime.SchemeBuilder AddToScheme = localSchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: webhook.GroupName, Version: "v1alpha1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type WebhookConfiguration ¶
type WebhookConfiguration struct {
metav1.TypeMeta `json:",inline"`
// securePort is the port number to listen on for secure TLS connections from the kube-apiserver.
// If 0, a random available port will be chosen.
// Defaults to 6443.
SecurePort *int32 `json:"securePort,omitempty"`
// healthzPort is the port number to listen on (using plaintext HTTP) for healthz connections.
// If 0, a random available port will be chosen.
// Defaults to 6080.
HealthzPort *int32 `json:"healthzPort,omitempty"`
// tlsConfig is used to configure the secure listener's TLS settings.
TLSConfig sharedv1alpha1.TLSConfig `json:"tlsConfig"`
// kubeConfig is the kubeconfig file used to connect to the Kubernetes apiserver.
// If not specified, the webhook will attempt to load the in-cluster-config.
KubeConfig string `json:"kubeConfig,omitempty"`
// apiServerHost is used to override the API server connection address.
// Deprecated: use `kubeConfig` instead.
APIServerHost string `json:"apiServerHost,omitempty"`
// enablePprof configures whether pprof is enabled.
EnablePprof bool `json:"enablePprof"`
// pprofAddress configures the address on which /debug/pprof endpoint will be served if enabled.
// Defaults to 'localhost:6060'.
PprofAddress string `json:"pprofAddress,omitempty"`
// logging configures the logging behaviour of the webhook.
// https://pkg.go.dev/k8s.io/component-base@v0.27.3/logs/api/v1#LoggingConfiguration
Logging logsapi.LoggingConfiguration `json:"logging"`
// featureGates is a map of feature names to bools that enable or disable experimental
// features.
// +optional
FeatureGates map[string]bool `json:"featureGates,omitempty"`
}
func (*WebhookConfiguration) DeepCopy ¶
func (in *WebhookConfiguration) DeepCopy() *WebhookConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WebhookConfiguration.
func (*WebhookConfiguration) DeepCopyInto ¶
func (in *WebhookConfiguration) DeepCopyInto(out *WebhookConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WebhookConfiguration) DeepCopyObject ¶
func (in *WebhookConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
Click to show internal directories.
Click to hide internal directories.